@@ -1,20 +1,18 @@
 import io
 import itertools
 import logging
+from typing import TYPE_CHECKING
 from typing import Tuple, List, Union, Optional
 
 import numpy as np
-from ipyleaflet import Map as LeafletMap, ScaleControl, FullScreenControl, Polyline, Icon, Marker, GeoData, \
-    LayersControl, basemaps, basemap_to_tiles, Circle, LayerGroup
+from ipyleaflet import Map as LeafletMap, ScaleControl, FullScreenControl, Polyline, Icon, Marker, LayersControl, \
+    basemaps, basemap_to_tiles, Circle, LayerGroup
 from ipywidgets import HTML
 
-from pyridy.file import RDYFile
-from pyridy.osm.utils.elements import OSMRailwaySignal, OSMRailwaySwitch, OSMLevelCrossing, OSMResultNode, \
-    OSMRailwayElement
-from pyridy.utils import GPSSeries
 from pyridy import config
-
-from typing import TYPE_CHECKING
+from pyridy.file import RDYFile
+from pyridy.osm.utils.elements import OSMRailwaySignal, OSMRailwaySwitch, OSMLevelCrossing, OSMResultNode
+from pyridy.utils import GPSSeries
 
 if TYPE_CHECKING:
     from pyridy.campaign import Campaign
@@ -33,7 +31,9 @@ class Map(LeafletMap):
             scroll_wheel_zoom=True,
             basemap=config.OPEN_STREET_MAP_DE,
         )
-        super().__init__(**(defaults | kwargs))
+        defaults.update(kwargs)
+
+        super().__init__(**defaults)
         self._set_up_controls()
         self._add_tile_layers()
 
